#
# spec file for package php7-libphutil
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           php7-libphutil
%define lib_name libphutil
Version:        0.0~git.20190930T091802~39ed96c
Release:        bp155.2.12
Summary:        Phabrcator PHP utility classes
License:        Apache-2.0
Group:          Development/Libraries/Other

URL:            https://github.com/phacility/libphutil/
Source0:        %{lib_name}-%{version}.tar.xz

BuildArch:      noarch

BuildRequires:  ca-certificates
BuildRequires:  php7-devel
BuildRequires:  xz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

Requires:       ca-certificates
Requires:       php7
Requires:       php7-curl
Requires:       php7-fileinfo
Requires:       php7-mbstring
Requires:       php7-xmlreader

%description
libphutil is a collection of utility classes and functions for PHP. It is used
by Phabricator and Arcanist.

Some of the major components of libphutil are:
* Core Utilities: a collection of useful functions like ipull() which simplify
  common data manipulation;
* Filesystem: classes like Filesystem which provide a strict API for filesystem
  access and throw exceptions on failure, making it easier to write robust code
  which interacts with files;
* Command Execution: libphutil provides a powerful system command primitive in
  ExecFuture which makes it far easier to write command-line scripts which
  execute system commands (see Command Execution);
* xsprintf(): allows you to define sprintf()-style functions which use custom
  conversions; and
* Library System: an introspectable, inventoried system for organizing PHP code
  and managing dependencies, supported by static analysis.


%prep
%setup -q -n %{lib_name}-%{version}

# remove tests
find src/ -name __tests__ -type d -print0 | xargs -0 rm -rf

%build

%install
install -d -m 0755 %{buildroot}%{_datadir}/phabricator/%{lib_name}
cp -a scripts/ src/ externals/ %{buildroot}%{_datadir}/phabricator/%{lib_name}/

find %{buildroot}%{_datadir}/phabricator/%{lib_name}/scripts/ -type f | \
    xargs sed -i '1 s|/usr/bin/env\ php|/usr/bin/php7|'

install -d -m 0755 %{buildroot}%{_datadir}/phabricator/%{lib_name}/resources/ssl
ln -s /var/lib/ca-certificates/ca-bundle.pem %{buildroot}%{_datadir}/phabricator/%{lib_name}/resources/ssl/default.pem

%files
%defattr(-,root,root,-)
%doc NOTICE README.md
%license LICENSE
%dir %{_datadir}/phabricator
%dir %{_datadir}/phabricator/%{lib_name}
%{_datadir}/phabricator/%{lib_name}/externals
%{_datadir}/phabricator/%{lib_name}/scripts
%{_datadir}/phabricator/%{lib_name}/src
%{_datadir}/phabricator/%{lib_name}/resources

%changelog
* Mon Jan 13 2020 i@guoyunhe.me
- Update to version 0.0~git.20190930T091802~39ed96c:
  * Fix "implode()" argument order in query string construction
  * Move PhutilProseDiff out of "libphutil/"
  * Ignore all files in "src/extensions/", not just immediate children
  * Remove "Web Application Only" classes from libphutil
  * Add a rough "ProgressSink" for improved progress reporting flexibility
  * Allow HTTPSFuture to stream very large files directly to disk
  * Force HTTP/1.1 in HTTPSFuture until HTTP/2 support stabilizes
  * Improve coverage of remarkup "<table>" rule and fix some bad method calls
  * When parsing HTML in remarkup, always start a new tag when encountering "<"
  * Fix some remarkup issues with selective construction of child nodes after HTML DOM parsing
* Wed Sep 18 2019 Yunhe Guo <i@guoyunhe.me>
- Disable _service for Factory submit
* Tue Sep 17 2019 Yunhe Guo <i@guoyunhe.me>
- Update to git version f51f1b3
- Change branch to master because it is more reliable than stable
* Tue Sep  4 2018 Andreas Schneider <asn@cryptomilk.org>
- Update to git version d5dde4c
* Mon Aug 21 2017 asn@cryptomilk.org
- Update to git version ee5ebf6:
  * Make "fail quietly" flag in DeferredLog a little more quiet
  * Stabilize sort order for Remarkup block rules
  * In Remarkup, prevent "%%%%%%" on a line from self-terminating the literal block
  * Don't fatal when encountering [[ <bad URI > | ... ]]
  * Modernize editor selector
  * Make empty Remarkup table rows have more intuitive behavior
  * If the overseer can't update the PID file, just move on
  * Don't warn about use of "Throwable" under PHP5
  * Consolidate binary (hg, git, svn) analysis code into one place
  * Increase strictness of URI parsing, rejecting URIs in the form "ssh://-flag"
* Mon Jun 19 2017 asn@cryptomilk.org
- Use the system cacert bundle
* Wed Jun 14 2017 asn@cryptomilk.org
- Initial package
